@@ -8,7 +8,6 @@ import aiohttp
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.primitives.asymmetric import padding
-
 from .login_const import APP_ID, PUBLIC_KEY_PEM, BASE_URL
 from .const import (
     SUPPORTED_COUNTRYS,
@@ -20,8 +19,15 @@ from .const import (
     CONF_REFRESH_TOKEN,
     CONF_TERMINAL,
     CONF_APP_ID,
+    CONF_REGION,
+    CONF_COUNTRY,
+    CONF_USERNAME,
+    CONF_PASSWORD,
+    CONF_CODE,
+    CONF_TOKEN,
+    ServerErrorCode
 )
-from .exceptions import AidotAuthFailed
+from .exceptions import AidotAuthFailed,AidotUserOrPassIncorrect
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -52,11 +58,13 @@ class AidotClient:
 
     def __init__(
         self,
+        session: Optional[ClientSession],
         country_name: str | None = None,
         username: str | None = None,
         password: str | None = None,
         token: dict | None = None,
     ) -> None:
+        self.session = session
         self.country_name = country_name
         self.username = username
         self.password = password
@@ -66,9 +74,20 @@ class AidotClient:
                 self._region = item["region"].lower()
                 self._base_url = f"https://prod-{self._region}-api.arnoo.com/v17"
                 break
+        if token is not None:
+            self.username = token[CONF_USERNAME]
+            self.password = token[CONF_PASSWORD]
+            self._region = token[CONF_REGION]
+            self.country_name = token[CONF_COUNTRY]
+
+    def set_token_fresh_cb(self, callback):
+        self._token_fresh_cb = callback
 
     def get_identifier(self) -> str:
-        return f"{self.username}-{self.password}-{self._region}"
+        return f"{self._region}-{self.username}"
+    
+    def update_password(self, password: str):
+        self.password = password
 
     async def async_post_login(self):
         """Login the user input allows us to connect."""
@@ -85,12 +104,18 @@ class AidotClient:
         }
 
         try:
-            async with self.session.post(url, headers=headers, json=data) as response:
-                response.raise_for_status()
-                self.login_info = await response.json()
-                return self.login_info
+            response = await self.session.post(url, headers=headers, json=data)
+            response_data = await response.json()
+            response.raise_for_status()
+            self.login_info = response_data
+            self.login_info[CONF_PASSWORD] = self.password
+            self.login_info[CONF_REGION] = self._region
+            self.login_info[CONF_COUNTRY] = self.country_name
+            return self.login_info
         except aiohttp.ClientError as e:
-            _LOGGER.info("async_post_login ClientError {e}")
+            _LOGGER.info(f"async_post_login ClientError {e}")
+            if response_data[CONF_CODE] == ServerErrorCode.USER_PWD_INCORRECT:
+                raise AidotUserOrPassIncorrect
             return None
 
     async def async_refresh_token(self):
@@ -101,13 +126,20 @@ class AidotClient:
         }
 
         try:
-            async with self.session.post(url, headers=headers, json=data) as response:
-                response.raise_for_status()
-                data = await response.json()
-                self.login_info[CONF_ACCESS_TOKEN] = data[CONF_ACCESS_TOKEN]
-                return data
+            response = await self.session.post(url, headers=headers, json=data)
+            response_data = await response.json()
+            response.raise_for_status()
+            self.login_info[CONF_ACCESS_TOKEN] = response_data[CONF_ACCESS_TOKEN]
+            if response_data[CONF_REFRESH_TOKEN] is not None:
+                self.login_info[CONF_REFRESH_TOKEN] = response_data[CONF_REFRESH_TOKEN]
+            _LOGGER.info(f"refresh token {response_data}")
+            if self._token_fresh_cb:
+                self._token_fresh_cb()
+            return response_data
         except aiohttp.ClientError as e:
-            _LOGGER.info("async_post_login ClientError {e}")
+            _LOGGER.info(f"async_refresh_token ClientError {e}")
+            if response_data[CONF_CODE] == ServerErrorCode.LOGIN_INVALID:
+                raise AidotAuthFailed
             return None
 
     async def async_session_get(self, params: str, headers: str | None = None):
@@ -118,16 +150,26 @@ class AidotClient:
         if headers is None:
             headers = {
                 CONF_TERMINAL: "app",
-                "Token": token,
+                CONF_TOKEN: token,
                 CONF_APP_ID: APP_ID,
             }
         try:
-            async with self.session.get(url, headers=headers) as response:
-                response.raise_for_status()
-                response_data = await response.json()
-                return response_data
+            response = await self.session.get(url, headers=headers)
+            response_data = await response.json()
+            response.raise_for_status()
+            return response_data
         except aiohttp.ClientError as e:
-            _LOGGER.info("async_get_products ClientError {e}")
+            _LOGGER.info(f"async_get ClientError {e}")
+            code = response_data[CONF_CODE]
+            if code == ServerErrorCode.TOKEN_EXPIRED:
+                try:
+                    await self.async_refresh_token()
+                    return await self.async_session_get(params)
+                except AidotAuthFailed:
+                    raise AidotAuthFailed
+            elif code == ServerErrorCode.LOGIN_INVALID or code == 21027 or code == 21041:
+                self.login_info[CONF_ACCESS_TOKEN] = None
+                raise AidotAuthFailed
             return None
 
     async def async_get_products(self, product_ids: str):
@@ -140,27 +182,29 @@ class AidotClient:
         params = f"/devices?houseId={house_id}"
         return await self.async_session_get(params)
 
-    async def async_get_houses(self, token: str):
+    async def async_get_houses(self):
         """Get house list."""
         params = "/houses"
         return await self.async_session_get(params)
 
     async def async_get_all_device(self):
-        # get houses
-        houses = await self.async_get_houses()
         final_device_list: list[dict[str, Any]] = []
-        for house in houses:
-            # get device_list
-            device_list = await self.async_get_devices(house[CONF_ID])
-            if device_list:
-                final_device_list.extend(device_list)
+        try:
+            houses = await self.async_get_houses()
+            for house in houses:
+                # get device_list
+                device_list = await self.async_get_devices(house[CONF_ID])
+                if device_list:
+                    final_device_list.extend(device_list)
 
-        # get product_list
-        productIds = ",".join([item[CONF_PRODUCT_ID] for item in device_list])
-        product_list = await self.async_get_products(productIds)
+            # get product_list
+            productIds = ",".join([item[CONF_PRODUCT_ID] for item in final_device_list])
+            product_list = await self.async_get_products(productIds)
 
-        for product in product_list:
-            for device in final_device_list:
-                if device[CONF_PRODUCT_ID] == product[CONF_ID]:
-                    device[CONF_PRODUCT] = product
+            for product in product_list:
+                for device in final_device_list:
+                    if device[CONF_PRODUCT_ID] == product[CONF_ID]:
+                        device[CONF_PRODUCT] = product
+        except Exception as e:
+            raise e
         return final_device_list
