@@ -1,4 +1,4 @@
-from enum import StrEnum
+from enum import StrEnum,IntEnum
 SUPPORTED_COUNTRYS = [
     {"_id": "1-0", "id": "AL", "name": "Albania", "ext": "", "region": "EU"},
     {
@@ -166,11 +166,17 @@ DEFAULT_COUNTRY_NAME = "United States"
 CONF_APP_ID = "Appid"
 CONF_TERMINAL = "Terminal"
 CONF_LOGIN_RESPONSE = "login_response"
+CONF_LOGIN_INFO = "login_info"
 CONF_SELECTED_HOUSE = "selected_house"
 CONF_DEVICE_LIST = "device_list"
 CONF_PRODUCT_LIST = "product_list"
 CONF_ACCESS_TOKEN = "accessToken"
 CONF_REFRESH_TOKEN = "refreshToken"
+CONF_TOKEN = "Token"
+CONF_USERNAME = "username"
+CONF_PASSWORD = "password"
+CONF_REGION = "region"
+CONF_COUNTRY = "country"
 CONF_ID = "id"
 CONF_NAME = "name"
 CONF_PRODUCT_ID = "productId"
@@ -188,7 +194,7 @@ CONF_PROPERTIES = "properties"
 CONF_MINVALUE = "minValue"
 CONF_MAXVALUE = "maxValue"
 CONF_IPADDRESS = "ipAddress"
-
+CONF_CODE = "code"
 class Identity(StrEnum):
     """Available entity identity."""
     RGBW = "control.light.rgbw"
@@ -197,4 +203,9 @@ class Identity(StrEnum):
 class Attribute(StrEnum):
     """Available entity attributes."""
     RGBW = "rgbw"
-    CCT = "cct"
\ No newline at end of file
+    CCT = "cct"
+
+class ServerErrorCode(IntEnum):
+    TOKEN_EXPIRED = 21026
+    LOGIN_INVALID = 21025
+    USER_PWD_INCORRECT = 560080
\ No newline at end of file
